-- 
-- create-tst-tables.sql
--
-- Test Script for simulating MySQL Crash.
--
-- -----------------------------------------------------------------------

DROP TABLE tab_raw;

CREATE TABLE tab_raw
(
   id1 INT NOT NULL,
   id2 INT NOT NULL,
   valueType INT NOT NULL,
   value DOUBLE NOT NULL,
   `minValue` DOUBLE DEFAULT NULL,
   `maxValue` DOUBLE DEFAULT NULL,
   timeStamp DATETIME NOT NULL,
   timePeriod TINYINT NOT NULL,
   validity TINYINT NOT NULL,
   opsType TINYINT NOT NULL
) ENGINE=innodb ROW_FORMAT=COMPRESSED
PARTITION BY RANGE ( to_days(timeStamp))  
( 
partition p0 values less than (to_days('2012-07-16 00:00:00')), 
partition p1 values less than (to_days('2012-07-17 00:00:00'))
);

create INDEX tab_raw_idx1 on tab_raw (id1,id2);
create INDEX tab_raw_idx2 on tab_raw (id2);
create INDEX tab_raw_idx3 on tab_raw (valueType);
create INDEX tab_raw_idx4 on tab_raw (timeStamp asc);

/* INSERT executes successfully. */
INSERT INTO tab_raw (id1, id2, valueType, value, `minValue`, `maxValue`, timeStamp, timePeriod, validity, opsType) 
	     values (10, 20, 30, 40, 50, 60, '2012-07-16 00:00:10', 80, 90, 100);

/* INSERT fails as partition does not exist. */
INSERT INTO tab_raw (id1, id2, valueType, value, `minValue`, `maxValue`, timeStamp, timePeriod, validity, opsType) 
             values (11, 21, 31, 41, 51, 61, '2012-07-17 00:00:10', 81, 91, 101);

/* SELECT crashes the DB as partition does not exist. */
INSERT INTO tab_raw (id1, id2, valueType, value, `minValue`, `maxValue`, timeStamp, timePeriod, validity, opsType) 
SELECT * 
FROM tab_raw
WHERE timeStamp >= '2012-07-17 00:00:01';
